@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dynamic-spaces" "0.0.1"
+(define-package "dynamic-spaces" "20250102.736"
   "Don't move text separated by multiple spaces."
   ()
   :url "https://github.com/Lindydancer/dynamic-spaces"
